@@ -5,24 +5,28 @@ Version: 0.1.1
 '''
 
 import os
+from pyfiglet import figlet_format
 
 class Shell:
     '''
     Create new Shell object
     '''
-    def __init__(self, name, show_cwd=False, prefix="[>] "):
+    def __init__(self, name, show_cwd=False, prefix="[>] ", figlet=False, figlet_font="standard"):
         self._name = name
         self._show_cwd = show_cwd
         self._prefix = prefix
         self._commands = {}
         self._help = "COMMAND: DESCRIPTION"
+        self._figlet = figlet
+        self._figlet_font = figlet_font
+        self._looping = True
 
     # --- main loop function ---
     def _loop(self):
         '''
         main loop waiting for input angel du geile sau
         '''
-        while True:
+        while self._looping:
             if self._show_cwd:
                 inp = input(f"{os.getcwd()} {self._prefix}")
             else:
@@ -44,6 +48,7 @@ class Shell:
                 print("")
             else:
                 # continue loop if inp == 0
+                self.stop()
                 continue
     # -------------------------
 
@@ -64,6 +69,14 @@ class Shell:
             raise CommandAlreadyExistError(cmd)
     # ------------------------------
 
+    # --- break loop ---
+    def stop(self):
+        '''
+        break out of main loop
+        '''
+        self._looping = False
+    # --------------------
+
     # --- build help function ---
     def _build_help(self):
         for cmd in self._commands:
@@ -102,6 +115,9 @@ class Shell:
         self.add_command("clear", self._cmd_clear, "clears the screen (unix)")
         # create help string
         self._build_help()
+        # splash
+        if self._figlet:
+            print(figlet_format(self._name, self._figlet_font))
         # start main loop
         self._loop()
     # ------------------
@@ -117,5 +133,5 @@ class CommandAlreadyExistError(Exception):
 
 
 if __name__ == "__main__":
-    sh = Shell("hi", True,)
+    sh = Shell("levish", show_cwd=True, figlet=True, figlet_font="3-d")
     sh.run()
\ No newline at end of file
